<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sikofitt\DoughnutWeddingBundle\Entity\Contact;
use Sikofitt\DoughnutWeddingBundle\Form\ContactFormType;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class DefaultController.
 */
class DefaultController extends Controller
{
    /**
     * @Route("/")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function indexAction(Request $request)
    {
        $parameters = [];
        if (null !== $this->getUser()) {
            $parameters['hide_social'] = true;
        }

        return $this->render('default/index.html.twig', $parameters);
    }

    /**
     * @Route("/our_story")
     *
     * @param \Symfony\Component\HttpFoundation\Request $request
     *
     * @return Response
     */
    public function ourStoryAction(Request $request): Response
    {
        return $this->render('our_story.html.twig');
    }

    /**
     * @Route("/location")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function locationAction(Request $request): Response
    {
        return $this->render('location.html.twig');
    }

    /**
     * @Route("/get_in_touch")
     *
     * @param \Symfony\Component\HttpFoundation\Request $request
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function contactAction(Request $request): Response
    {
        $contact = new Contact();
        if (null !== $this->getUser()) {
            $contact
              ->setName($this->getUser()->getName())
              ->setEmail($this->getUser()->getEmail())
              ->setUserId($this->getUser()->getId())
            ;
        }

        $form = $this->get('form.factory')->create(ContactFormType::class, $contact);

        if ($request->isMethod('POST')) {
            $form->handleRequest($request);
            if ($form->isValid() && $form->isSubmitted()) {
                $em = $this->get('doctrine.orm.entity_manager');
                /** @var Contact $data */
                $data = $form->getData();

                $data->setCreatedAt(new \DateTime('now'));

                $em->persist($data);
                $em->flush();

                $responseMessage[] = 'Thank you for your message '.$data->getName().'!';

                $email = $data->getEmail();

                if (null !== $email) {
                    $responseMessage[] = sprintf('We will respond to you at %s as soon as possible.', $email);
                } else {
                    $email = 'no-reply@doughnutwedding.com';
                }

                $message = new \Swift_Message();
                $message->setSubject($data->getSubject());
                $message->setFrom($email);
                $message->setTo([
                  $this->getParameter('katrina.email') => 'Katrina Johnson',
                  $this->getParameter('eric.email') => 'R. Eric Wheeler',
                ]);
                $message->setBody($data->getComment());

                $this->get('swiftmailer.mailer')->send($message);

                return $this->render('form/contact.html.twig',
                  ['message' => $responseMessage]);
            }
        }

        return $this->render('form/contact.html.twig', ['form' => $form->createView()]);
    }
}
