<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\HttpFoundation\File\File;
use Symfony\Component\HttpFoundation\File\UploadedFile;
use Vich\UploaderBundle\Mapping\Annotation as Vich;

/**
 * Image.
 *
 * @Vich\Uploadable()
 * @ORM\Table(name="image")
 * @ORM\Entity(repositoryClass="Sikofitt\DoughnutWeddingBundle\Repository\ImageRepository")
 */
class Image
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var UploadedFile
     *
     * @Vich\UploadableField(mapping="gallery_image", fileNameProperty="imageName", size="imageSize")
     */
    private $imageFile;

    /**
     * @var string
     *
     * @ORM\Column(type="string", length=255)
     */
    private $imageName;

    /**
     * @var \Sikofitt\DoughnutWeddingBundle\Entity\User
     *
     * @ORM\ManyToOne(targetEntity="Sikofitt\DoughnutWeddingBundle\Entity\User", inversedBy="images")
     */
    private $user;

    /**
     * @var \Sikofitt\DoughnutWeddingBundle\Entity\ImageComment
     *
     * @ORM\OneToMany(targetEntity="Sikofitt\DoughnutWeddingBundle\Entity\ImageComment", mappedBy="image", cascade={"remove"})
     */
    private $comments;

   /**
    * @var string
    *
    * @ORM\Column(name="tags", type="json_array", nullable=true, unique=false)
    */
   private $tags;

   /**
    * @var string
    *
    * @ORM\Column(name="category", type="string", length=255, nullable=true, unique=false)
    */
   private $category;

   /**
    * @var string
    *
    * @ORM\Column(name="description", type="text", nullable=true, unique=false)
    */
   private $description;

   /**
    * @var bool
    *
    * @ORM\Column(name="is_published", type="boolean")
    */
   private $isPublished = true;

   /**
    * @var \DateTimeImmutable
    *
    * @ORM\Column(name="updated_at", type="datetime", nullable=true)
    */
   private $updatedAt;

    public function __construct()
    {
        $this->comments = new ArrayCollection();
    }

    public function __toString()
    {
        return $this->imageName;
    }

    /**
     * Get id.
     *
     * @return int
     */
    public function getId(): ?int
    {
        return $this->id;
    }

  /**
   * @return string
   */
  public function getDescription(): ?string
  {
      return $this->description;
  }

  /**
   * @param string $description
   *
   * @return Image
   */
  public function setDescription(?string $description): Image
  {
      $this->description = $description;

      return $this;
  }

    public function getComments(): ?Collection
    {
        return $this->comments;
    }

    /**
     * @param \Doctrine\Common\Collections\ArrayCollection|null $comments
     *
     * @return \Sikofitt\DoughnutWeddingBundle\Entity\Image
     */
    public function setComments(?ArrayCollection $comments): Image
    {
        $this->comments = $comments;

        return $this;
    }

  /**
   * @param \Sikofitt\DoughnutWeddingBundle\Entity\ImageComment|null $comment
   */
  public function addComment(ImageComment $comment = null): void
  {
      $this->comments[] = $comment;
  }

  /**
   * @param \Sikofitt\DoughnutWeddingBundle\Entity\ImageComment|null $comment
   *
   * @return \Sikofitt\DoughnutWeddingBundle\Entity\Image
   */
  public function removeComment(ImageComment $comment = null): Image
  {
      $this->comments->removeElement($comment);

      return $this;
  }

  /**
   * @return bool
   */
  public function isIsPublished(): bool
  {
      return $this->isPublished;
  }

  /**
   * @param bool $isPublished
   *
   * @return Image
   */
  public function setIsPublished(bool $isPublished): Image
  {
      $this->isPublished = $isPublished;

      return $this;
  }

  /**
   * @return \DateTimeInterface
   */
  public function getUpdatedAt(): ?\DateTimeInterface
  {
      return $this->updatedAt;
  }

  /**
   * @param \DateTimeInterface $updatedAt
   *
   * @return Image
   */
  public function setUpdatedAt(\DateTimeInterface $updatedAt): Image
  {
      $this->updatedAt = $updatedAt;

      return $this;
  }

    /**
     * Set imageFile.
     *
     * @param File|UploadedFile $imageFile
     *
     * @return Image
     */
    public function setImageFile(?File $imageFile): Image
    {
        $this->imageFile = $imageFile;
        if ($imageFile) {
            $this->updatedAt = new \DateTimeImmutable();
        }

        return $this;
    }

    /**
     * Get imageFile.
     *
     * @return File|null
     */
    public function getImageFile(): ?File
    {
        return $this->imageFile;
    }

    /**
     * Set imageName.
     *
     * @param string $imageName
     *
     * @return Image
     */
    public function setImageName(?string $imageName): Image
    {
        $this->imageName = $imageName;

        return $this;
    }

    /**
     * Get imageName.
     *
     * @return string
     */
    public function getImageName(): ?string
    {
        if (null === $this->imageName && null !== $this->imageFile) {
            return $this->imageFile->getFilename();
        }

        return $this->imageName;
    }

    /**
     * Set user.
     *
     * @param User $user
     *
     * @return Image
     */
    public function setUser(?User $user): Image
    {
        $this->user = $user;

        return $this;
    }

    /**
     * Get user.
     *
     * @return User
     */
    public function getUser(): ?User
    {
        return $this->user;
    }

    /**
     * Set tags.
     *
     * @param array $tags
     *
     * @return Image
     */
    public function setTags($tags): Image
    {
        foreach ($tags as $key => $value) {
            if (null === $value || '' === $value) {
                unset($tags[$key]);
            }
        }
        $this->tags = $tags;

        return $this;
    }

    /**
     * Get tags.
     *
     * @return array|string
     */
    public function getTags()
    {
        if (true === is_array($this->tags)) {
            foreach ((array) $this->tags as $key => $value) {
                if (null === $value || '' === $value) {
                    unset($this->tags[$key]);
                }
            }
        }

        return $this->tags;
    }

    /**
     * Set category.
     *
     * @param string $category
     *
     * @return Image
     */
    public function setCategory($category): ?Image
    {
        $this->category = $category;

        return $this;
    }

    /**
     * Get category.
     *
     * @return string
     */
    public function getCategory(): ?string
    {
        return $this->category;
    }
}
