<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/** @noinspection ClassOverridesFieldOfSuperClassInspection */

/**
 * Class User.
 *
 * @ORM\Entity(repositoryClass="Sikofitt\DoughnutWeddingBundle\Repository\UserRepository")
 * @ORM\Table(name="users")
 */
class User extends \FOS\UserBundle\Model\User
{
    const KATRINA_SIDE = 'Katrina';

    const ERIC_SIDE = 'Eric';

  /**
   * @ORM\Id()
   * @ORM\Column(name="id", type="integer", nullable=false, unique=true)
   * @ORM\GeneratedValue(strategy="IDENTITY")
   *
   * @var int
   */
  protected $id;

  /**
   * @ORM\Column(name="fullname", type="string", length=255, nullable=false)
   * @Assert\NotBlank()
   * @Assert\Regex(pattern="/\w+/")
   */
  private $name;

  /**
   * @var \Sikofitt\DoughnutWeddingBundle\Entity\Rsvp
   * @ORM\OneToOne(targetEntity="Sikofitt\DoughnutWeddingBundle\Entity\Rsvp", inversedBy="user",
   *                                                                          cascade={"persist"})
   */
  private $rsvp;

  /**
   * @ORM\Column(type="datetime", name="created")
   */
  private $created;

  /**
   * @ORM\Column(type="datetime", name="updated")
   */
  private $updated;

  /**
   * @var \Doctrine\Common\Collections\ArrayCollection
   *
   * @ORM\OneToMany(targetEntity="Sikofitt\DoughnutWeddingBundle\Entity\Image", mappedBy="user")
   */
  private $images;

  /**
   * @var \Sikofitt\DoughnutWeddingBundle\Entity\ImageComment
   *
   * @ORM\OneToMany(targetEntity="Sikofitt\DoughnutWeddingBundle\Entity\ImageComment", mappedBy="user")
   */
  private $imageComment;

  /**
   * @var string
   *
   * @ORM\Column(name="comments", type="text", nullable=true)
   */
  private $comment;

  /**
   * @ORM\Column(name="facebook_id", type="string", length=255, nullable=true)
   */
  private $facebookId;

    private $facebookAccessToken;

  /**
   * @ORM\Column(name="google_id", type="string", length=255, nullable=true)
   */
  private $googleId;

    private $googleAccessToken;

  /**
   * @ORM\Column(name="amazon_id", type="string", length=255, nullable=true)
   */
  private $amazonId;

    private $amazonAccessToken;

  /**
   * @ORM\Column(name="instagram_id", type="string", length=255, nullable=true)
   */
  private $instagramId;

    private $instagramAccessToken;

  /**
   * @ORM\Column(name="twitter_id", type="string", length=255, nullable=true)
   */
  private $twitterId;

    private $twitterAccessToken;

  /**
   * @ORM\Column(name="yahoo_id", type="string", length=255, nullable=true)
   */
  private $yahooId;

    private $yahooAccessToken;

  /**
   * User constructor.
   */
  public function __construct()
  {
      $this->imageComment = new ArrayCollection();
      if (null === $this->created) {
          $this->created = new \DateTime('now');
      }
      $this->updated = new \DateTime('now');
      parent::__construct();
  }

    public function setImageComment($imageComment)
    {
        $this->imageComment = $imageComment;

        return $this;
    }

    public function getImageComment()
    {
        return $this->imageComment;
    }

    public function addImageComment(ImageComment $imageComment)
    {
        $imageComment->setUser($this);
        $this->imageComment[] = $imageComment;

        return $this;
    }

    public function removeImageComment(ImageComment $imageComment)
    {
        $imageComment->setUser(null);
        $this->imageComment->removeElement($imageComment);
    }

    public function getComment(): ?string
    {
        return $this->comment;
    }

    public function setComment(?string $comment): User
    {
        $this->comment = $comment;

        return $this;
    }

  /**
   * @return mixed
   */
  public function getAmazonId(): ?string
  {
      return $this->amazonId;
  }

  /**
   * @param string $amazonId
   *
   * @return User
   */
  public function setAmazonId(?string $amazonId): User
  {
      $this->amazonId = $amazonId;

      return $this;
  }

  /**
   * @return string
   */
  public function getAmazonAccessToken(): ?string
  {
      return $this->amazonAccessToken;
  }

  /**
   * @param string $amazonAccessToken
   *
   * @return User
   */
  public function setAmazonAccessToken(?string $amazonAccessToken): User
  {
      $this->amazonAccessToken = $amazonAccessToken;

      return $this;
  }

  /**
   * @return string
   */
  public function getFacebookId(): ?string
  {
      return $this->facebookId;
  }

  /**
   * @param mixed $facebookId
   *
   * @return User
   */
  public function setFacebookId(string $facebookId): User
  {
      $this->facebookId = $facebookId;

      return $this;
  }

  /**
   * @return string
   */
  public function getFacebookAccessToken(): ?string
  {
      return $this->facebookAccessToken;
  }

  /**
   * @param string $facebookAccessToken
   *
   * @return User
   */
  public function setFacebookAccessToken(?string $facebookAccessToken): User
  {
      $this->facebookAccessToken = $facebookAccessToken;

      return $this;
  }

  /**
   * @return string
   */
  public function getGoogleId(): ?string
  {
      return $this->googleId;
  }

  /**
   * @param string $googleId
   *
   * @return User
   */
  public function setGoogleId(?string $googleId): User
  {
      $this->googleId = $googleId;

      return $this;
  }

  /**
   * @return string
   */
  public function getGoogleAccessToken(): ?string
  {
      return $this->googleAccessToken;
  }

  /**
   * @param string $googleAccessToken
   *
   * @return User
   */
  public function setGoogleAccessToken(?string $googleAccessToken): User
  {
      $this->googleAccessToken = $googleAccessToken;

      return $this;
  }

  /**
   * @return string
   */
  public function getInstagramId(): ?string
  {
      return $this->instagramId;
  }

  /**
   * @param string $instagramId
   *
   * @return User
   */
  public function setInstagramId(?string $instagramId): User
  {
      $this->instagramId = $instagramId;

      return $this;
  }

  /**
   * @return mixed
   */
  public function getInstagramAccessToken(): ?string
  {
      return $this->instagramAccessToken;
  }

  /**
   * @param string $instagramAccessToken
   *
   * @return User
   */
  public function setInstagramAccessToken(?string $instagramAccessToken): User
  {
      $this->instagramAccessToken = $instagramAccessToken;

      return $this;
  }

  /**
   * @return string
   */
  public function getTwitterId(): ?string
  {
      return $this->twitterId;
  }

  /**
   * @param string $twitterId
   *
   * @return User
   */
  public function setTwitterId(?string $twitterId): User
  {
      $this->twitterId = $twitterId;

      return $this;
  }

  /**
   * @return mixed
   */
  public function getTwitterAccessToken()
  {
      return $this->twitterAccessToken;
  }

  /**
   * @param string $twitterAccessToken
   *
   * @return User
   */
  public function setTwitterAccessToken(?string $twitterAccessToken): User
  {
      $this->twitterAccessToken = $twitterAccessToken;

      return $this;
  }

  /**
   * @return string
   */
  public function getYahooId(): ?string
  {
      return $this->yahooId;
  }

  /**
   * @param string $yahooId
   *
   * @return User
   */
  public function setYahooId(?string $yahooId): User
  {
      $this->yahooId = $yahooId;

      return $this;
  }

  /**
   * @return string
   */
  public function getYahooAccessToken(): ?string
  {
      return $this->yahooAccessToken;
  }

  /**
   * @param string $yahooAccessToken
   *
   * @return User
   */
  public function setYahooAccessToken(?string $yahooAccessToken): User
  {
      $this->yahooAccessToken = $yahooAccessToken;

      return $this;
  }

  /**
   * Get Name.
   *
   * @return string
   */
  public function getName(): ?string
  {
      return $this->name;
  }

  /**
   * Set Name.
   *
   * @param string $name
   *
   * @return User
   */
  public function setName(string $name): User
  {
      $this->name = $name;

      return $this;
  }

  /**
   * @param string $plainPassword
   *
   * @return User
   */
  public function setPlainPassword($plainPassword): User
  {
      $this->plainPassword = $plainPassword;

      return $this;
  }

  /**
   * Get created.
   *
   * @return \DateTime
   */
  public function getCreated(): ?\DateTime
  {
      return $this->created;
  }

  /**
   * Set created.
   *
   * @param \DateTime $created
   *
   * @return User
   */
  public function setCreated(?\DateTime $created): User
  {
      $this->created = $created;

      return $this;
  }

  /**
   * Get updated.
   *
   * @return \DateTime
   */
  public function getUpdated(): ?\DateTime
  {
      return $this->updated;
  }

  /**
   * Set updated.
   *
   * @param \DateTime $updated
   *
   * @return User
   */
  public function setUpdated(?\DateTime $updated): User
  {
      $this->updated = $updated;

      return $this;
  }

  /**
   * Get rsvp.
   *
   * @return Rsvp
   */
  public function getRsvp(): ?Rsvp
  {
      return $this->rsvp;
  }

  /**
   * Set rsvp.
   *
   * @param Rsvp $rsvp
   *
   * @return User
   */
  public function setRsvp(Rsvp $rsvp = null): User
  {
      $this->rsvp = $rsvp;

      return $this;
  }

  /**
   * Add image.
   *
   * @param \Sikofitt\DoughnutWeddingBundle\Entity\Image $image
   *
   * @return User
   */
  public function addImage(Image $image): User
  {
      $image->setUser($this);

      $this->images[] = $image;

      return $this;
  }

  /**
   * Remove image.
   *
   * @param \Sikofitt\DoughnutWeddingBundle\Entity\Image $image
   */
  public function removeImage(Image $image): void
  {
      $image->setUser(null);

      $this->images->removeElement($image);
  }

  /**
   * Get images.
   *
   * @return \Doctrine\Common\Collections\Collection
   */
  public function getImages()
  {
      return $this->images;
  }
}
