<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\EventListener;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;


class CheckForMaintenanceModeListenerEvent
{
    private $container;
    private $token;

    public function __construct(ContainerInterface $container, TokenStorageInterface $token)
    {
        $this->container = $container;
        $this->token = $token;
    }

    public function onKernelRequest(GetResponseEvent $event)
    {
        $maintenance = (bool) $this->container->getParameter('maintenance');

        if (null === $maintenance || false === $maintenance) {
            return;
        }

        $authToken = $this->token->getToken();
        if (
      null !== $authToken &&
      true === $this->container
        ->get('security.authorization_checker')
        ->isGranted('ROLE_ADMIN', $authToken)
    ) {
            $event
        ->getRequest()
        ->getSession()
        ->getFlashBag()
        ->set('warning', 'Maintenance mode is on.');

            return;
        }

        $event->setResponse(new Response($this->container->get('twig')
      ->render('maintenance.html.twig')));
    }
}
