<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\EventListener;

use Symfony\Component\HttpKernel\Event\FilterResponseEvent;

/**
 * Adds a flash message for login redirects.
 *
 * Class NeedToAuthenticateListenerEvent
 */
class NeedToAuthenticateListenerEvent
{
    /**
     * Adds a flash message for login redirects.
     *
     * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
     */
    public function onKernelResponse(FilterResponseEvent $event): void
    {
        if (null !== $event->getRequest()->getUser()) {
            if (
              true === $event
                ->getResponse()
                ->headers
                ->has('location') &&
              false !== strpos($event->getResponse()->headers->get('location'),
                '/login') &&
              true === $event
                ->getRequest()
                ->getSession()
                ->has('_security.secured_area.target_path')
            ) {
                $targetPath = $event
                  ->getRequest()
                  ->getSession()
                  ->get('_security.secured_area.target_path');
                $message = sprintf('You need to login to view %s', $targetPath);

                $event
                  ->getRequest()
                  ->getSession()
                  ->getFlashBag()
                  ->add('warning', $message);
            }
        }
    }
}
