<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\EventListener;

use FOS\UserBundle\Event\FilterUserResponseEvent;
use HWI\Bundle\OAuthBundle\Security\Core\Authentication\Token\OAuthToken;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\Security\Core\User\UserInterface;
use Symfony\Component\Security\Http\Event\InteractiveLoginEvent;

/**
 * Class RedirectOnUserRegisterListener.
 */
class RedirectOnUserRegisterListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    /**
     * RedirectOnUserRegisterListener constructor.
     *
     * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
     */
    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @param \FOS\UserBundle\Event\FilterUserResponseEvent $event
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function onFosuserRegistrationCompleted(FilterUserResponseEvent $event): ?RedirectResponse
    {
        $user = $event->getUser();
        $this->sendRegistrationEmail($user, 'the Default Sign up form');
        $url = $this
          ->container
          ->get('router')
          ->generate('sikofitt_doughnutwedding_default_index');

        return new RedirectResponse($url);
    }

    /**
     * Sends an email if the user has registered with a OAuth
     * Unfortunately HWIOAuthBundle does not have events, and does not call
     * the FOSUserBundle register events if using the bridge, so we have to
     * do it here in the InteractiveLoginEvent listener because it's the only
     * event HWIOAuthBundle calls.
     *
     * @param \Symfony\Component\Security\Http\Event\InteractiveLoginEvent $event
     */
    public function onSecurityInteractivelogin(InteractiveLoginEvent $event): void
    {
        // Match the registration path so we don't call this on all logins.
        if (preg_match('/(connect\/registration\/\d+)/', $event->getRequest()->getRequestUri())) {
            $user = $event->getAuthenticationToken()->getUser();
            $resourceOwnerName = null;
            if ($event->getAuthenticationToken() instanceof OAuthToken) {
                /** @var OAuthToken $token */
                $token = $event->getAuthenticationToken();
                $resourceOwnerName = $token->getResourceOwnerName();
            }
            $this->sendRegistrationEmail($user, $resourceOwnerName);
        }
    }

    /**
     * @param \Symfony\Component\Security\Core\User\UserInterface $user
     * @param null|string                                         $resourceOwner
     */
    public function sendRegistrationEmail(UserInterface $user, string $resourceOwner = null): void
    {
        $message = new \Swift_Message('[Doughnut Wedding] User registered');
        $body = $this->container->get('twig')->render('user_registered.txt.twig.html.twig', ['user' => $user, 'resourceOwner' => $resourceOwner]);

        $message
          ->setFrom(['no-reply@doughnutwedding.com' => '[Doughnut Wedding]'])
          ->setTo([
            $this->container->getParameter('katrina.email') => 'Katrina Johnson',
            $this->container->getParameter('eric.email') => 'R. Eric Wheeler',
          ])->setBody($body);

        $this->container->get('swiftmailer.mailer')->send($message);
    }
}
