<?php

declare(strict_types=1);

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\EventListener;

use Symfony\Bundle\FrameworkBundle\Routing\Router;
use Symfony\Component\{
  EventDispatcher\EventDispatcherInterface, HttpFoundation\RedirectResponse, HttpKernel\Event\GetResponseEvent, Security\Core\Authentication\Token\Storage\TokenStorageInterface
};

class UserRedirectOnLoggedInListener
{
    /**
     * @var TokenStorageInterface
     */
    private $tokenStorage;

    /**
     * @var Router
     */
    private $router;

  /**
   * UserRedirectOnLoggedInListener constructor.
   *
   * @param TokenStorageInterface $tokenStorage
   * @param Router                $router
   */
  public function __construct(
    TokenStorageInterface $tokenStorage,
    Router $router
  ) {
      $this->tokenStorage = $tokenStorage;
      $this->router = $router;
  }

  /**
   * Redirects logged in users to the profile page, from the login page.
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
   *
   * @throws \InvalidArgumentException
   */
  public function onKernelRequest(GetResponseEvent $event): void
  {
      $token = $this->tokenStorage->getToken();

      if (null !== $token) {
          $pathInfo = $event->getRequest()->getPathInfo();
          $routeInformation = $this->router->match($pathInfo);
          $profile = $this->router->generate('fos_user_profile_show');

          if (
            true === $this->shouldRedirectRoute($routeInformation) &&
            null !== $token->getUser() &&
            false === strpos($token->getUsername(), 'anon')
          ) {
              $event->setResponse(new RedirectResponse($profile));
          }
      }
  }

  /**
   * Decides if we should redirect the current route
   * depending on whether or not we are logged in.
   *
   * @param array $routeInformation
   *
   * @return bool
   */
  private function shouldRedirectRoute(array $routeInformation): bool
  {
      return true === in_array(
        $routeInformation['_route'],
            $this->getRedirectRoutes(),
            true
        );
  }

  /**
   * @return array
   *               Routes that we should redirect
   */
  private function getRedirectRoutes(): array
  {
      return [
        'fos_user_security_login',
        'fos_user_registration_confirmed',
        'fos_user_resetting_request',
        'fos_user_registration_register',
      ];
  }
}
