<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Factory;

use Google\Auth\Credentials\ServiceAccountCredentials;
use Google_Service_Storage;

class GoogleCloudStorageServiceFactory
{
    /**
   * @param string $credentialFile
   * @param string $clientId
   * @param string $applicationName
   *
   * @throws \ErrorException
   * @throws \InvalidArgumentException
   *
   * @return \Google_Service_Storage
   */
  public static function createGoogleCloudService(string $credentialFile, string $clientId, string $applicationName): \Google_Service_Storage
  {
      if (false === file_exists($credentialFile)) {
          throw new \ErrorException(sprintf('File %s does not exist.', $credentialFile));
      }
      if (false === is_readable($credentialFile)) {
          throw new \ErrorException(sprintf('File %s is not readable.  Check permissions.', $credentialFile));
      }

      $jsonStr = file_get_contents($credentialFile);
      if (null === $credentials = json_decode($jsonStr, true)) {
          throw new \ErrorException('Could not decode google json credentials');
      }

      $client = new \Google_Client();
      $client->setClientId($clientId);
      $client->setApplicationName($applicationName);

      $cred = ServiceAccountCredentials::makeCredentials(
      Google_Service_Storage::DEVSTORAGE_FULL_CONTROL,
      $credentials
    );
      $token = $cred->fetchAuthToken();
      $client->setAccessToken($token);

      return  new \Google_Service_Storage($client);
  }
}
