<?php

declare(strict_types=1);

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Form;

use Sikofitt\DoughnutWeddingBundle\Entity\Contact;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Email;
use Symfony\Component\Validator\Constraints\Length;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\NotNull;

/**
 * Class ContactFormType.
 */
class ContactFormType extends AbstractType
{
    /**
   * {@inheritdoc}
   */
  public function buildForm(FormBuilderInterface $builder, array $options): void
  {
      $builder
      ->add('name', TextType::class, [
        'label_attr' => [
          'class' => 'uk-form-label uk-visible@m',
        ],
        'label' => 'Name',
        'attr' => [
          'class' => 'uk-padding-small uk-input uk-form-large uk-margin-small-bottom',
          'placeholder' => 'Enter your name',
        ],
        'required' => true,
        'trim' => true,
        'constraints' => [
          new NotBlank(),
          new NotNull(),
          new Length(['max' => 255, 'min' => 5]),
        ],
      ])
      ->add('email', EmailType::class, [
        'label_attr' => [
          'class' => 'uk-form-label uk-visible@m',
        ],
        'label' => 'Email (Not required)',
        'attr' => [
          'class' => 'uk-padding-small uk-input uk-form-large uk-margin-small-bottom',
          'placeholder' => 'Email address (not required)',
          'autocomplete' => 'off',
          'autocorrect' => 'off',
          'autocapitalize' => 'off',
          'spellcheck' => 'false',
        ],
        'required' => false,
        'trim' => true,
        'constraints' => [
          new Email([
            'checkMX' => true,
            'checkHost' => true,
            'strict' => true,
          ]),
        ],
      ])
      ->add('subject', TextType::class, [
        'label_attr' => [
          'class' => 'uk-form-label uk-visible@m',
        ],
        'label' => 'Subject',
        'attr' => [
          'class' => 'uk-padding-small uk-input uk-form-large uk-margin-small-bottom',
          'placeholder' => 'Enter a subject for your comment.',
        ],
        'required' => true,
        'trim' => true,
        'constraints' => [
          new NotBlank(),
          new NotNull(),
          new Length(['max' => 255, 'min' => 5]),
        ],
      ])
      ->add('comment', TextareaType::class, [
        'label_attr' => [
          'class' => 'uk-form-label uk-visible@m',
        ],
        'label' => 'Comment',
        'attr' => [
          'rows' => 4,
          'class' => 'uk-padding-small uk-textarea uk-form-large uk-margin-medium-bottom',
          'placeholder' => 'Enter your comment',
        ],
        'required' => true,
        'constraints' => [
          new NotBlank(),
          new NotNull(),
        ],
      ])
    ->add('submit', SubmitType::class, [
     'label' => 'Send',
        'attr' => [
          'class' => 'uk-button uk-button-primary uk-button-large uk-width-1-1',
        ],
    ]);
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Symfony\Component\OptionsResolver\Exception\AccessException
   */
  public function configureOptions(OptionsResolver $resolver): void
  {
      $resolver->setDefault('data_class', Contact::class);
      $resolver->setDefault('attr', ['class' => 'uk-form uk-form-horizontal']);
  }

  /**
   * {@inheritdoc}
   */
  public function getBlockPrefix(): ?string
  {
      return 'sikofitt_doughnut_wedding_contact';
  }
}
