<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Form;

use FOS\UserBundle\Form\Type\ProfileFormType;
use FOS\UserBundle\Model\UserManager;
use Sikofitt\DoughnutWeddingBundle\Entity\Rsvp;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\CallbackTransformer;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;

class ProfileEditType extends AbstractType
{
    private $userManager;

    public function __construct(UserManager $userManager)
    {
        $this->userManager = $userManager;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $emailOptions = $builder->get('email')->getOptions();

        $builder->remove('current_password');
        $builder->remove('username');
        $builder->remove('email');
        $emailOptions['attr'] = [
          'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
          'placeholder' => 'Email Address',
        ];
        $emailOptions['label_attr'] = [
          'class' => 'uk-form-label uk-text-primary',
        ];
        $builder->add('email', EmailType::class, $emailOptions);
        $builder->add('name', TextType::class, [
          'attr' => [
            'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
            'placeholder' => 'Name',
          ],
          'label' => 'Name',
          'label_attr' => [
            'class' => 'uk-form-label uk-text-primary',
          ],
        ]);
        $builder->add('rsvp', IntegerType::class, [
          'attr' => [
            'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
            'placeholder' => 'Number of Guests (including yourself)',
          ],
          'label' => 'Number of guests? (including yourself)',
          'label_attr' => [
            'class' => 'uk-form-label uk-text-primary',
          ],
        ]);

        $builder->addEventListener(FormEvents::SUBMIT, function (FormEvent $event) {
            $user = $event->getData();
            $user->setUsername($user->getEmail());
            $this->userManager->updateCanonicalFields($user);
        });
        $builder->get('rsvp')
          ->addModelTransformer(new CallbackTransformer(
            function (?Rsvp $rsvp) {
                if (null === $rsvp) {
                    return $rsvp;
                }

                return $rsvp->getGuests();
            },
            function (Int $rsvpInt) {
                $rsvp = new Rsvp();
                $rsvp->setGuests($rsvpInt);

                return $rsvp;
            }
          ));
    }

    public function getParent()
    {
        return ProfileFormType::class;
    }
}
