<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Form;

use FOS\UserBundle\Form\Type\RegistrationFormType;
use FOS\UserBundle\Model\UserManager;
use HWI\Bundle\OAuthBundle\OAuth\Response\PathUserResponse;
use Sikofitt\DoughnutWeddingBundle\Entity\Rsvp;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\CallbackTransformer;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\Form\FormView;
use Symfony\Component\OptionsResolver\OptionsResolver;

class RegistrationType extends AbstractType
{
    private $userManager;

    public function __construct(UserManager $userManager)
    {
        $this->userManager = $userManager;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder->add('name', TextType::class)
        ->add('rsvp', NumberType::class, [
          'required' => false,
          'empty_data' => '0',
          'attr' => [
            'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
            'placeholder' => 'Number of Guests (including yourself)',
          ],
          'label' => 'Number of guests? (including yourself)',
          'label_attr' => [
            'class' => 'uk-form-label uk-text-primary',
          ],
        ])
          ->add('comment', TextareaType::class, [
            'required' => false,
            'label' => 'Anything you would like to share with the Bride and Groom?',
            'label_attr' => [
              'class' => 'uk-form-label uk-visible@m',
            ],
            'attr' => [
              'rows' => 5,
              'class' => 'uk-textarea uk-form-large uk-padding-small',
              'placeholder' => 'Anything you would like to share with the Bride and Groom?',
            ],
          ])
          ->remove('username');

        $builder->addEventListener(FormEvents::SUBMIT, function (FormEvent $event) {
            $user = $event->getData();
            $user->setUsername($user->getEmail());
            $this->userManager->updateCanonicalFields($user);
        });

        $builder->get('rsvp')
        ->addModelTransformer(new CallbackTransformer(
          function (?Rsvp $rsvp) {
              if (null === $rsvp) {
                  return $rsvp;
              }

              return $rsvp->getGuests();
          },
          function (Int $rsvpInt) {
              $rsvp = new Rsvp();
              $rsvp->setGuests($rsvpInt);

              return $rsvp;
          }
        ));
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefault('attr', ['class' => 'uk-form uk-form-horizontal']);
    }

    public function getParent()
    {
        return RegistrationFormType::class;
    }

    public function finishView(
      FormView $view,
      FormInterface $form,
      array $options
    ) {
        $view->children['email']->vars['attr']['class'] = 'uk-input';
        $view->children['email']->vars['label_attr']['class'] = 'uk-form-label';
        $p = new PathUserResponse();
        //$p->getResourceOwner()->getName();
    }

    public function getBlockPrefix()
    {
        return 'sikofitt_doughnut_wedding_bundle_registration_type';
    }
}
