<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\App\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\RepeatedType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Length;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\NotNull;

/**
 * Class ResetPasswordType.
 */
class ResetPasswordType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('password', RepeatedType::class, [
                'type' => PasswordType::class,
                'invalid_message' => 'Passwords do not match.',
                'invalid_message_parameters' => [
                    'class' => 'uk-text-danger',
                ],
                'required' => true,
                'options' => [
                    'always_empty' => false,
                    'attr' => [
                        'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    ],
                    'label_attr' => [
                        'class' => 'uk-form-label',
                    ],
                    'constraints' => [
                        new NotBlank(),
                        new NotNull(),
                    ],
                ],
                'first_options' => [
                    'label' => 'New password',
                    'constraints' => [
                        new Length(['min' => 8, 'minMessage' => 'Password must be at least 8 characters.']),
                    ],
                ],
                'second_options' => [
                    'label' => 'Repeat your password',
                ],
            ])
            ->add('submit', SubmitType::class, [
                'attr' => [
                    'class' => 'uk-button uk-button-primary uk-button-large',
                ],
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefault('attr', ['class' => 'uk-form uk-form-horizontal']);
    }
}
