<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Form;

use Sikofitt\DoughnutWeddingBundle\Entity\Rsvp;
use Sikofitt\DoughnutWeddingBundle\Entity\User;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\CallbackTransformer;
use Symfony\Component\Form\Extension\Core\Type\{
    CheckboxType,
    ChoiceType,
    EmailType,
    IntegerType,
    PasswordType,
    RadioType,
    TextType
};
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class RsvpType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('firstname', TextType::class, [
                'attr' => [
                     'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    'placeholder' => 'First Name',
                ],
                'label' => 'First name',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ])
            ->add('lastname', TextType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    'placeholder' => 'Last Name',
                ],
                'label' => 'Last name',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ])
            ->add('email', EmailType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    'placeholder' => 'Email address',
                ],
                'label' => 'Email address',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ])
            ->add('plainPassword', PasswordType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    'placeholder' => 'Password',
                ],
                'label' => 'Password',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ])
            ->add('rsvp', IntegerType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-padding-small',
                    'placeholder' => 'Number of Guests (including yourself)',
                ],
                'label' => 'Number of guests? (including yourself)',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ])
            ->add('familyside', ChoiceType::class, [
                'choices' => [
                    User::ERIC_SIDE => User::ERIC_SIDE,
                    User::KATRINA_SIDE => User::KATRINA_SIDE,
                ],
                'attr' => [
                    'class' => 'uk-select uk-form-large uk-box-shadow-hover-small',
                    'style' => 'padding-left:16px;',
                ],
                'label' => 'Who are you coming for?',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ])
            ->add('family', CheckboxType::class, [
                'label' => 'Are you a family member?',
                'required' => false,
                'attr' => [
                    'class' => 'uk-checkbox uk-box-shadow-hover-small',
                    'style' => 'padding-left:16px;',
                ],
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
            ]);
        $builder->get('rsvp')
            ->addModelTransformer(new CallbackTransformer(
                function ($rsvp) {
                    if (null === $rsvp) {
                        return $rsvp;
                    } else {
                        return $rsvp->getGuests();
                    }
                },
                function (Int $rsvpInt) {
                    $rsvp = new Rsvp();
                    $rsvp->setGuests($rsvpInt);

                    return $rsvp;
                }
            ));
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefault('data_class', User::class);
        $resolver->setDefault('attr', ['class' => 'uk-form-horizontal uk-margin-large']);
    }
}
