<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\App\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Email;
use Symfony\Component\Validator\Constraints\NotBlank;

class UserLoginType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('email_username', TextType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    'placeholder' => 'Email address',
                ],
                'label' => 'Email address',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
                'constraints' => [
                    new NotBlank(),
                    new Email([
                        'strict' => true,
                        'checkMX' => true,
                        'checkHost' => true,
                        'message' => 'Invalid email address.',
                    ]),
                ],
            ])->add('password', PasswordType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-padding-small uk-box-shadow-hover-small',
                    'placeholder' => 'Password',
                ],
                'label' => 'Password',
                'label_attr' => [
                    'class' => 'uk-form-label uk-text-primary',
                ],
                'constraints' => [
                    new NotBlank(),
                ],
            ])->add('submit', SubmitType::class, [
                'attr' => [
                    'class' => 'uk-button uk-button-primary',
                ],
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefault('attr', ['class' => 'uk-form uk-form-horizontal']);
    }
}
