<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\App\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Email;
use Symfony\Component\Validator\Constraints\Length;

class UserTokenType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('user_token', TextType::class, [
                'attr' => [
                    'class' => 'uk-input uk-form-large',
                    'placehoder' => 'Token',
                ],
                'required' => false,
                'label_attr' => [
                    'class' => 'uk-form-label uk-hidden',
                ],
                'constraints' => [
                    new Length([
                        'min' => 64,
                        'max' => 64,
                        'minMessage' => 'Token should be exactly {{ limit }} characters.',
                        'maxMessage' => 'Token should be exactly {{ limit }} characters.',
                        'exactMessage' => 'Token should be exactly {{ limit }} characters.',
                    ]),
                ],
            ])->add('submit', SubmitType::class, [
                'attr' => [
                    'class' => 'uk-button uk-button-large uk-button-primary',
                ],
                'label' => 'Login',
            ])->add('email', EmailType::class, [
                'required' => false,
                'constraints' => [
                    new Email([
                        'strict' => true,
                        'checkMX' => true,
                        'checkHost' => true,
                    ]),
                ],
                'attr' => [
                    'class' => 'uk-input uk-form-large uk-text-center',
                    'placeholder' => 'Email Address',
                ],
                'label_attr' => [
                    'class' => 'uk-form-label',
                ],
            ])->add('update_token', SubmitType::class, [
                'attr' => [
                    'class' => 'uk-button uk-button-large uk-button-primary',
                ],
                'label' => 'Send New Login Link',
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefault('attr', ['class' => 'uk-form uk-align-center']);
    }
}
