<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Pager\View;

use Pagerfanta\View\Template\Template;

class UIkitTemplate extends Template
{
    protected static $defaultOptions = [
      'prev_message' => '&larr; Previous',
      'next_message' => 'Next &rarr;',
      'dots_message' => '&hellip;',
      'active_suffix' => '',
      'css_container_class' => 'uk-pagination uk-flex-center',
      'css_prev_class' => 'prev',
      'css_next_class' => 'next',
      'css_disabled_class' => 'disabled',
      'css_dots_class' => 'disabled',
      'css_active_class' => 'active',
      'rel_previous' => 'prev',
      'rel_next' => 'next',
    ];

    /**
     * Renders the container for the pagination.
     *
     * The %pages% placeholder will be replaced by the rendering of pages
     *
     * @return string
     */
    public function container()
    {
        return sprintf('<ul class="%s" uk-margin>%s</ul>', static::$defaultOptions['css_container_class'], '%pages%');
    }

    /**
     * Renders a given page.
     *
     * @param int $page
     *
     * @return string
     */
    public function page($page)
    {
        if (1 === (int) $page) {
            return '<li><a href="/gallery">'.$page.'</a></li>';
        }

        return '<li><a href="/gallery/page/'.$page.'">'.$page.'</a></li>';
    }

    /**
     * Renders a given page with a specified text.
     *
     * @param int    $page
     * @param string $text
     *
     * @return string
     */
    public function pageWithText($page, $text)
    {
        return $this->page($page);
    }

    /**
     * Renders the disabled state of the previous page.
     *
     * @return string
     */
    public function previousDisabled()
    {
        return '';
    }

    /**
     * Renders the enabled state of the previous page.
     *
     * @param int $page
     *
     * @return string
     */
    public function previousEnabled($page)
    {
        if (1 === (int) $page) {
            return '<li><a href="/gallery"><span class="uk-margin-small-right" uk-pagination-previous></span> Previous</a></li>';
        }

        return '<li><a href="/gallery/page/'.$page.'"><span class="uk-margin-small-right" uk-pagination-previous></span> Previous</a></li>';
    }

    /**
     * Renders the disabled state of the next page.
     *
     * @return string
     */
    public function nextDisabled()
    {
        return '';
    }

    /**
     * Renders the enabled state of the next page.
     *
     * @param int $page
     *
     * @return string
     */
    public function nextEnabled($page)
    {
        return '<li class=""><a href="/gallery/page/'.$page.'">Next <span class="uk-margin-small-left" uk-pagination-next></span></a></li>';
    }

    /**
     * Renders the first page.
     *
     * @return string
     */
    public function first()
    {
        return '';
    }

    /**
     * Renders the last page.
     *
     * @param int $page
     *
     * @return string
     */
    public function last($page)
    {
        return '';
    }

    /**
     * Renders the current page.
     *
     * @param int $page
     *
     * @return string
     */
    public function current($page)
    {
        return '<li class="uk-active"><span>'.$page.'</span></li>';
    }

    /**
     * Renders the separator between pages.
     *
     * @return string
     */
    public function separator()
    {
        return '<li class="uk-disabled"><span> ... </span></li>';
    }
}
