<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\DoughnutWeddingBundle\Security;

use Psr\Log\LoggerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\Security\Http\Authorization\AccessDeniedHandlerInterface;

/**
 * Class AccessDeniedHandler.
 */
class AccessDeniedHandler implements AccessDeniedHandlerInterface
{
    /**
     * @var UrlGeneratorInterface
     */
    private $router;

    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * Sets up the router.
     *
     * @param UrlGeneratorInterface $router
     * @param LoggerInterface       $logger
     */
    public function __construct(UrlGeneratorInterface $router, LoggerInterface $logger)
    {
        $this->router = $router;
        $this->logger = $logger;
    }

    /**
     * Redirects to the login page on access denied failure.
     *
     * @param Request               $request
     * @param AccessDeniedException $accessDeniedException
     *
     * @return RedirectResponse
     */
    public function handle(Request $request, AccessDeniedException $accessDeniedException): RedirectResponse
    {
        /** @var \Symfony\Component\HttpFoundation\Session\Session $session */
        $session = $request->getSession();
        $session->getFlashBag()->add('error', $accessDeniedException->getMessage());
        $url = $this->router->generate('fos_user_security_login');
        $this->logger->alert($accessDeniedException->getMessage(), [
          'code' => $accessDeniedException->getCode(),
          'attributes' => $accessDeniedException->getAttributes(),
          'subject' => $accessDeniedException->getSubject(),
        ]);

        return new RedirectResponse($url, 302, [
          'X-Denied-Message' => $accessDeniedException->getMessage(),
          'X-Denied-Status-Code' => $accessDeniedException->getCode(),
        ]);
    }
}
