<?php

/*
 *     doughnutwedding.com
 *     Copyright (C) 2017  http://doughnutwedding.com eric@doughnutwedding.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\Security;

use Symfony\Component\Security\Core\Encoder\PasswordEncoderInterface;

class ScryptEncoder implements PasswordEncoderInterface
{
    /**
     * Encodes the raw password.
     *
     * @param string $raw  The password to encode
     * @param string $salt The salt
     *
     * @return string The encoded password
     */
    public function encodePassword($raw, $salt)
    {
        $salt = $this->generateSalt();
        $hash = \scrypt($raw, $salt, 16384, 8, 1, 32);

        return 16384 .'$'. 8 .'$'. 1 .'$'.$salt.'$'.$hash;
    }

    /**
     * Checks a raw password against an encoded password.
     *
     * @param string $encoded An encoded password
     * @param string $raw     A raw password
     * @param string $salt    The salt
     *
     * @return bool true if the password is valid, false otherwise
     */
    public function isPasswordValid($encoded, $raw, $salt)
    {
        $salt = null;
        // Is there actually a hash?
        if (!$encoded) {
            return false;
        }
        list($N, $r, $p, $salt, $hash) = explode('$', $encoded);
        // No empty fields?
        if (empty($N) or empty($r) or empty($p) or empty($salt) or empty($hash)) {
            return false;
        }
        // Are numeric values numeric?
        if (!is_numeric($N) or !is_numeric($r) or !is_numeric($p)) {
            return false;
        }
        $calculated = \scrypt($raw, $salt, $N, $r, $p, 32);
        // Use compareStrings to avoid timeing attacks
        return $this->compareStrings($hash, $calculated);
    }

    private function compareStrings($expected, $actual)
    {
        $expected = (string) $expected;
        $actual = (string) $actual;
        $lenExpected = \mb_strlen($expected);
        $lenActual = \mb_strlen($actual);
        $len = min($lenExpected, $lenActual);
        $result = 0;
        for ($i = 0; $i < $len; ++$i) {
            $result |= ord($expected[$i]) ^ ord($actual[$i]);
        }
        $result |= $lenExpected ^ $lenActual;

        return $result === 0;
    }

    private function generateSalt()
    {
        $buffer = random_bytes(8);
        $salt = str_replace(['+', '$'], ['.', ''], base64_encode($buffer));

        return $salt;
    }
}
